@@ -102,21 +102,21 @@ KDiff3Plugin::KDiff3Plugin( KonqPopupMenu* pPopupmenu, const char *name, const T
    {
       int historyCount = s_pHistory ? s_pHistory->count() : 0;
       s = i18n("Compare with %1").arg( historyCount>0 ? s_pHistory->front() : TQString() );
-      pAction = new TDEAction ( s,0, this, TQT_SLOT(slotCompareWith()), actionCollection());
+      pAction = new TDEAction ( s,0, this, TQ_SLOT(slotCompareWith()), actionCollection());
       pAction->setEnabled( m_list.count()>0 && historyCount>0 );
       pActionMenu->insert (pAction);
 
       s = i18n("Merge with %1").arg( historyCount>0 ? s_pHistory->front() : TQString() );
-      pAction = new TDEAction( s, 0, this, TQT_SLOT(slotMergeWith()), actionCollection());
+      pAction = new TDEAction( s, 0, this, TQ_SLOT(slotMergeWith()), actionCollection());
       pAction->setEnabled( m_list.count()>0 && historyCount>0 );
       pActionMenu->insert (pAction);
 
       s = i18n("Save '%1' for later").arg( ( m_list.front() ) );
-      pAction = new TDEAction ( s, 0, this, TQT_SLOT(slotSaveForLater()), actionCollection());
+      pAction = new TDEAction ( s, 0, this, TQ_SLOT(slotSaveForLater()), actionCollection());
       pAction->setEnabled( m_list.count()>0 );
       pActionMenu->insert(pAction);
 
-      pAction = new TDEAction (i18n("3-way merge with base"), 0, this, TQT_SLOT(slotMergeThreeWay()), actionCollection());
+      pAction = new TDEAction (i18n("3-way merge with base"), 0, this, TQ_SLOT(slotMergeThreeWay()), actionCollection());
       pAction->setEnabled( m_list.count()>0 && historyCount>=2 );
       pActionMenu->insert (pAction);
 
@@ -127,26 +127,26 @@ KDiff3Plugin::KDiff3Plugin( KonqPopupMenu* pPopupmenu, const char *name, const T
          pActionMenu->insert(pHistoryMenu);
          for (TQStringList::iterator i = s_pHistory->begin(); i!=s_pHistory->end(); ++i)
          {
-            pAction = new TDEAction( *i, "History", 0, this, TQT_SLOT(slotCompareWithHistoryItem()), actionCollection());
+            pAction = new TDEAction( *i, "History", 0, this, TQ_SLOT(slotCompareWithHistoryItem()), actionCollection());
             pHistoryMenu->insert (pAction);
          }
 
-         pAction = new TDEAction (i18n("Clear list"), 0, this, TQT_SLOT(slotClearList()), actionCollection());
+         pAction = new TDEAction (i18n("Clear list"), 0, this, TQ_SLOT(slotClearList()), actionCollection());
          pActionMenu->insert (pAction);
          pAction->setEnabled( historyCount>0 );
       }
    }
    else if(m_list.count() == 2)
    {
-      pAction = new TDEAction (i18n("Compare"), 0, this, TQT_SLOT(slotCompareTwoFiles()), actionCollection());
+      pAction = new TDEAction (i18n("Compare"), 0, this, TQ_SLOT(slotCompareTwoFiles()), actionCollection());
       pActionMenu->insert (pAction);
    }
    else if ( m_list.count() == 3 )
    {
-      pAction = new TDEAction (i18n("3 way comparison"), 0, this, TQT_SLOT(slotCompareThreeFiles()), actionCollection());
+      pAction = new TDEAction (i18n("3 way comparison"), 0, this, TQ_SLOT(slotCompareThreeFiles()), actionCollection());
       pActionMenu->insert (pAction);
    }
-   pAction = new TDEAction (i18n("About KDiff3 menu plugin ..."), 0, this, TQT_SLOT(slotAbout()), actionCollection());
+   pAction = new TDEAction (i18n("About KDiff3 menu plugin ..."), 0, this, TQ_SLOT(slotAbout()), actionCollection());
    pActionMenu->insert (pAction);
 
    addSeparator();
