@@ -50,7 +50,7 @@ MergeResultWindow::MergeResultWindow(
    )
 : TQWidget( pParent, 0, WRepaintNoErase )
 {
-   setFocusPolicy( TQ_ClickFocus );
+   setFocusPolicy( TQWidget::ClickFocus );
 
    m_firstLine = 0;
    m_firstColumn = 0;
@@ -84,7 +84,7 @@ MergeResultWindow::MergeResultWindow(
    m_cursorYPos=0;
    m_bCursorOn = true;
    m_bCursorUpdate = false;
-   connect( &m_cursorTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT( slotCursorUpdate() ) );
+   connect( &m_cursorTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT( slotCursorUpdate() ) );
    m_cursorTimer.start( 500 /*ms*/, true /*single shot*/ );
    m_selection.reset();
 
@@ -1761,7 +1761,7 @@ void MergeResultWindow::paintEvent( TQPaintEvent*  )
       if ( size() != m_pixmap.size() )
          m_pixmap.resize(size());
 
-      MyPainter p(TQT_TQPAINTDEVICE(&m_pixmap), m_pOptionDialog->m_bRightToLeftLanguage, width(), fontWidth);
+      MyPainter p(&m_pixmap, m_pOptionDialog->m_bRightToLeftLanguage, width(), fontWidth);
       p.setFont( font() );
       p.TQPainter::fillRect( rect(), m_pOptionDialog->m_bgColor );
 
@@ -1843,7 +1843,7 @@ void MergeResultWindow::paintEvent( TQPaintEvent*  )
 
    if ( m_bCursorOn && hasFocus() && m_cursorYPos>=m_firstLine )
    {
-      MyPainter painter(TQT_TQPAINTDEVICE(this), m_pOptionDialog->m_bRightToLeftLanguage, width(), fontWidth);
+      MyPainter painter(this, m_pOptionDialog->m_bRightToLeftLanguage, width(), fontWidth);
       int topLineYOffset = 0;
       int xOffset = fontWidth * leftInfoWidth;
 
@@ -1929,9 +1929,9 @@ void MergeResultWindow::mousePressEvent ( TQMouseEvent* e )
    int pos;
    convertToLinePos( e->x(), e->y(), line, pos );
 
-   bool bLMB = e->button() == Qt::LeftButton;
-   bool bMMB = e->button() == Qt::MidButton;
-   bool bRMB = e->button() == Qt::RightButton;
+   bool bLMB = e->button() == TQt::LeftButton;
+   bool bMMB = e->button() == TQt::MidButton;
+   bool bRMB = e->button() == TQt::RightButton;
 
    if ( bLMB && pos < m_firstColumn || bRMB )       // Fast range selection
    {
@@ -1999,7 +1999,7 @@ void MergeResultWindow::mousePressEvent ( TQMouseEvent* e )
 
 void MergeResultWindow::mouseDoubleClickEvent( TQMouseEvent* e )
 {
-   if ( e->button() == Qt::LeftButton )
+   if ( e->button() == TQt::LeftButton )
    {
       int line;
       int pos;
@@ -2033,7 +2033,7 @@ void MergeResultWindow::mouseDoubleClickEvent( TQMouseEvent* e )
 
 void MergeResultWindow::mouseReleaseEvent ( TQMouseEvent * e )
 {
-   if ( e->button() == Qt::LeftButton )
+   if ( e->button() == TQt::LeftButton )
    {
       killTimer(m_delayedDrawTimer);
       m_delayedDrawTimer = 0;
@@ -3068,7 +3068,7 @@ WindowTitleWidget::WindowTitleWidget(OptionDialog* pOptionDialog, TQWidget* pPar
 
    //m_pBrowseButton = new TQPushButton("...");
    //pHLayout->addWidget( m_pBrowseButton, 0 );
-   //connect( m_pBrowseButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotBrowseButtonClicked()));
+   //connect( m_pBrowseButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotBrowseButtonClicked()));
 
    m_pModifiedLabel = new TQLabel(i18n("[Modified]"),this);
    pHLayout->addWidget( m_pModifiedLabel );
@@ -3199,7 +3199,7 @@ bool WindowTitleWidget::eventFilter( TQObject* o, TQEvent* e )
       m_pEncodingLabel->setPalette( p );
       m_pEncodingSelector->setPalette( p );
    }
-   if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_pFileNameLineEdit) && e->type()==TQEvent::Drop)
+   if (o == m_pFileNameLineEdit && e->type()==TQEvent::Drop)
    {
       TQDropEvent* d = static_cast<TQDropEvent*>(e);
 
@@ -3210,8 +3210,8 @@ bool WindowTitleWidget::eventFilter( TQObject* o, TQEvent* e )
 
          if ( lst.count() > 0 )
          {
-            static_cast<TQLineEdit*>(TQT_TQWIDGET(o))->setText( lst[0] );
-            static_cast<TQLineEdit*>(TQT_TQWIDGET(o))->setFocus();
+            static_cast<TQLineEdit*>(o)->setText( lst[0] );
+            static_cast<TQLineEdit*>(o)->setFocus();
             return true;
          }
       }
